@@ -1,15 +1,16 @@
 # coding: utf-8
 """A Jupyter-aware wrapper for the yarn package manager"""
 
+import os
+
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 import sys
 
-import os
-from jupyterlab_server.process import which, subprocess
+from jupyterlab_server.process import subprocess, which
 
 HERE = os.path.dirname(os.path.abspath(__file__))
-YARN_PATH = os.path.join(HERE, 'staging', 'yarn.js')
+YARN_PATH = os.path.join(HERE, "staging", "yarn.js")
 
 
 def execvp(cmd, argv):
@@ -22,9 +23,10 @@ def execvp(cmd, argv):
     (Python bug#9148).
     """
     cmd = which(cmd)
-    if os.name == 'nt':
+    if os.name == "nt":
         import signal
         import sys
+
         p = subprocess.Popen([cmd] + argv[1:])
         # Don't raise KeyboardInterrupt in the parent process.
         # Set this after spawning, to avoid subprocess inheriting handler.
@@ -36,8 +38,7 @@ def execvp(cmd, argv):
 
 
 def main(argv=None):
-    """Run node and return the result.
-    """
+    """Run node and return the result."""
     # Make sure node is available.
     argv = argv or sys.argv[1:]
-    execvp('node', ['node', YARN_PATH] + argv)
+    execvp("node", ["node", YARN_PATH] + argv)
